@@ -2,7 +2,7 @@ use std::str::FromStr;
 
 use serde::{Deserialize, Serialize};
 
-use ibc::ics24_host::identifier::ChainId;
+use ibc::core::ics24_host::identifier::ChainId;
 use ibc_relayer::{
     config::ChainConfig,
     rest::request::{Request, VersionInfo},
@@ -63,7 +63,7 @@ fn version() {
 
     let rest_api_version = VersionInfo {
         name: "ibc-relayer-rest".to_string(),
-        version: "0.7.3".to_string(),
+        version: "0.8.0".to_string(),
     };
 
     let result = vec![version.clone(), rest_api_version];
